Description Usage Arguments Details Value Author(s) Examples
Plot the probabilities of the first orden transition matrix for an mkv object.
1 2 |
m |
a matrix of n x n or a |
col |
a color vector containing two colours specified as |
xlab |
a |
ylab |
a |
title |
a |
cell.size |
an |
axis.size |
an |
tick.size |
an |
... |
Other arguments for |
A level plot based in a ggplot() graph. The level plot show the probabilities of transition form state i to the state j in gradual color from "low" color to "high" color, also show the probability of the transition in the (i,j) cell. If the matrix or the mkv are transitions, the matrix is transformed into a probabilities transition matrix by dividing the row by the row sum. Different ggplot theme can be creating by setting up a new theme() object.
A level plot of showing the probabilities of transitions between the differents classes.
Andres Vallone
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.