Description Usage Format Source Examples
A dataframe containing the per-capita income for the lower 48 US states in the priod 1929-2009dir(
. This data set also include states48.gal a spatial weigth matrix in a nb object and W a listw object cantaining the list of neighboors for the 48 states.
1 | data("USjoin")
|
A data frame whith 48 US states.
a character vector with the name of the state
a state index for mapping functions
1929 to 2009integer vector conatainin per capita income of the state in each period
The dataset is sxtracted for the PySAL project web site https://github.com/pysal/pysal/tree/master/pysal/examples/us_income
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.